Documentation
¶
Index ¶
- Constants
- type DelaySpec
- type ExecutionMetadata
- type Loop
- func (c *Loop) Cancel(ctx core.ExecutionContext) error
- func (c *Loop) Cleanup(ctx core.SetupContext) error
- func (c *Loop) Color() string
- func (c *Loop) Configuration() []configuration.Field
- func (c *Loop) Description() string
- func (c *Loop) Documentation() string
- func (c *Loop) ExampleOutput() map[string]any
- func (c *Loop) Execute(ctx core.ExecutionContext) error
- func (c *Loop) HandleHook(ctx core.ActionHookContext) error
- func (c *Loop) HandleWebhook(ctx core.WebhookRequestContext) (int, *core.WebhookResponseBody, error)
- func (c *Loop) Hooks() []core.Hook
- func (c *Loop) Icon() string
- func (c *Loop) Label() string
- func (c *Loop) Name() string
- func (c *Loop) OutputChannels(configuration any) []core.OutputChannel
- func (c *Loop) ProcessQueueItem(ctx core.ProcessQueueContext) (*uuid.UUID, error)
- func (c *Loop) Setup(ctx core.SetupContext) error
- type Spec
Constants ¶
const ( ChannelNameNext = "next" ChannelNameDone = "done" PayloadTypeNext = "loop.next" PayloadTypeDone = "loop.done" )
const ( DelayStrategyFixed = "fixed" DelayStrategyExponential = "exponential" DelayMinIntervalSeconds = 1 DelayMaxIntervalSeconds = 300 )
const ( // DefaultTimeoutSeconds caps the total wall-clock time of a single loop run // when one is not configured. It exists so a loop can never get stuck // forever (e.g. downstream never reports back), which would also block every // subsequent run on the node since runs are serialized. DefaultTimeoutSeconds = 3600 TimeoutMinSeconds = 1 TimeoutMaxSeconds = 86400 )
const ( StopReasonConditionMet = "conditionTrue" StopReasonMaxIterations = "max_iterations" )
const ComponentName = "loop"
const (
MaxIterationsLimit = 100
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExecutionMetadata ¶
type Loop ¶
type Loop struct{}
func (*Loop) Configuration ¶
func (c *Loop) Configuration() []configuration.Field
func (*Loop) Description ¶
func (*Loop) Documentation ¶
func (*Loop) ExampleOutput ¶
func (*Loop) HandleHook ¶
func (c *Loop) HandleHook(ctx core.ActionHookContext) error
func (*Loop) HandleWebhook ¶
func (c *Loop) HandleWebhook(ctx core.WebhookRequestContext) (int, *core.WebhookResponseBody, error)
func (*Loop) OutputChannels ¶
func (c *Loop) OutputChannels(configuration any) []core.OutputChannel
func (*Loop) ProcessQueueItem ¶
Click to show internal directories.
Click to hide internal directories.